aboutsummaryrefslogtreecommitdiffhomepage
path: root/Firestore/Source/Local/FSTLocalSerializer.h
diff options
context:
space:
mode:
authorGravatar zxu <zxu@google.com>2018-04-25 14:05:36 -0400
committerGravatar GitHub <noreply@github.com>2018-04-25 14:05:36 -0400
commitf9bd6d3c9491dddbfc9cbe0fcc633030a66fe9da (patch)
treea396dca81e1fc06d8870acad723e56175b75bd05 /Firestore/Source/Local/FSTLocalSerializer.h
parent5ecdcc5ae1132d2cc0d532e580b31f70369ef319 (diff)
Port `SnapshotVersion` for `Local` (#1182)
* no-brainer replace `FSTSnapshotVersion` with `SnapshotVersion` * refresh code * fix LocalStore * fix LocalStore (partial revert 78e6c38) * address changes
Diffstat (limited to 'Firestore/Source/Local/FSTLocalSerializer.h')
-rw-r--r--Firestore/Source/Local/FSTLocalSerializer.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/Firestore/Source/Local/FSTLocalSerializer.h b/Firestore/Source/Local/FSTLocalSerializer.h
index 6ca7f01..b75f3e6 100644
--- a/Firestore/Source/Local/FSTLocalSerializer.h
+++ b/Firestore/Source/Local/FSTLocalSerializer.h
@@ -16,11 +16,12 @@
#import <Foundation/Foundation.h>
+#include "Firestore/core/src/firebase/firestore/model/snapshot_version.h"
+
@class FSTMaybeDocument;
@class FSTMutationBatch;
@class FSTQueryData;
@class FSTSerializerBeta;
-@class FSTSnapshotVersion;
@class FSTPBMaybeDocument;
@class FSTPBTarget;
@@ -61,11 +62,11 @@ NS_ASSUME_NONNULL_BEGIN
/** Decodes an FSTPBTarget proto from local storage into an FSTQueryData model. */
- (FSTQueryData *)decodedQueryData:(FSTPBTarget *)target;
-/** Encodes an FSTSnapshotVersion model into a GPBTimestamp proto. */
-- (GPBTimestamp *)encodedVersion:(FSTSnapshotVersion *)version;
+/** Encodes a SnapshotVersion model into a GPBTimestamp proto. */
+- (GPBTimestamp *)encodedVersion:(const firebase::firestore::model::SnapshotVersion &)version;
-/** Decodes a GPBTimestamp proto into a FSTSnapshotVersion model. */
-- (FSTSnapshotVersion *)decodedVersion:(GPBTimestamp *)version;
+/** Decodes a GPBTimestamp proto into a SnapshotVersion model. */
+- (firebase::firestore::model::SnapshotVersion)decodedVersion:(GPBTimestamp *)version;
@end